viewdom_wired
=============

*Injectable and plugabble components and services for viewdom*

`Docs <https://viewdom_wired.readthedocs.io/en/latest/>`_ and `Code <https://github.com/pauleveritt/viewdom_wired>`_
